@@ -222,7 +222,8 @@ invoke_forecast_function <- function(fn_to_invoke,
 #' @param date_regex Date Regex
 #' @param fiscal_year_start Fiscal Year Start
 #' @param seasonal_periods Seasonal Periods
-#' We need to move these out using a scheduler
+#' @param pca run pca
+#' @param seed set random seed for modeling
 #' 
 #' @return a forecast_models function
 #' @noRd
@@ -251,13 +252,17 @@ construct_forecast_models <- function(full_data_tbl,
                                       date_regex,
                                       fiscal_year_start,
                                       seasonal_periods, 
-                                      pca
+                                      pca, 
+                                      seed
                                       ){
 
   forecast_models <- function(combo_value) {
     
     cli::cli_h2("Running Combo: {combo_value}")
     
+    # Set Seed
+    set.seed(seed)
+    
     # Copy functions into global environment within azure batch
     if(!is.null(parallel_processing)) {
       if(parallel_processing == "azure_batch") {
@@ -305,7 +310,6 @@ construct_forecast_models <- function(full_data_tbl,
       train_data_recipe_1 <- run_data_full_recipe_1 %>%
         dplyr::filter(Date <= hist_end_date)
       
-      
       test_data_recipe_1 <- run_data_full_recipe_1 %>%
         dplyr::filter(Date > hist_end_date)
       
@@ -328,7 +332,7 @@ construct_forecast_models <- function(full_data_tbl,
       
       train_data_recipe_2 <- run_data_full_recipe_2 %>%
         dplyr::filter(Date <= hist_end_date)
-      
+
       train_origins <- train_data_recipe_2 %>%
         dplyr::filter(Horizon == 1)
       
@@ -339,7 +343,7 @@ construct_forecast_models <- function(full_data_tbl,
                       Origin == train_origin_max+1)
       
     }
-    
+
     # create modeltime table to add single trained models to
     combined_models_recipe_1 <- modeltime::modeltime_table()
     combined_models_recipe_2 <- modeltime::modeltime_table()
@@ -379,6 +383,8 @@ construct_forecast_models <- function(full_data_tbl,
     # train each model
     for(model_name in models_to_go_over){
       
+      set.seed(seed)
+      
       model_fn <- as.character(model_list[model_name])
       
       cli::cli_alert_info("Function being called: {model_fn}")
@@ -648,8 +654,9 @@ construct_forecast_models <- function(full_data_tbl,
       models_to_go_over <- ensemble_models[ensemble_models %in% names(model_list)]
       
       for(model_name in models_to_go_over){
+
+        set.seed(seed)
         
-        #model_fn <- as.character(ensemble_models[model_name])
         model_fn <- gsub("-", "_", model_name)
         add_name <- paste0(model_name,"-ensemble",model_name_suffix)
         
